/*
 * Copyright (c) 2004 - 2007, Tranql project contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.tranql.connector.postgresql;

import java.sql.SQLException;
import org.postgresql.ds.PGConnectionPoolDataSource;
import org.tranql.connector.NoExceptionsAreFatalSorter;
import org.tranql.connector.jdbc.AbstractPooledConnectionDataSourceMCF;

/**
 * ManagedConnectionFactory that wraps a PGConnectionPoolDataSource.
 *
 * @version $Revision: 665 $ $Date: 2009-10-05 12:47:47 -0700 (Mon, 05 Oct 2009) $
 */
public class PGConnectionPooleMCF extends AbstractPooledConnectionDataSourceMCF<PGConnectionPoolDataSource> {

    /**
     * Default constructor for a PostgreSQL Local DataSource.
     */
    public PGConnectionPooleMCF() {
        super(new PGConnectionPoolDataSource(), new NoExceptionsAreFatalSorter());
    }

    /**
     * Return the user name used to establish the connection.
     *
     * @return the user name used to establish the connection
     */
    public String getUserName() {
        return connectionPoolDataSource.getUser();
    }

    /**
     * Set the user name used establish the connection. This value is used if no
     * connection information is supplied by the application when attempting to
     * create a connection.
     *
     * @param userName the user name used to establish the connection; may be null
     */
    public void setUserName(String userName) {
        connectionPoolDataSource.setUser(userName);
    }

    /**
     * Return the password credential used to establish the connection.
     *
     * @return the password credential used to establish the connection
     */
    public String getPassword() {
        return connectionPoolDataSource.getPassword();
    }

    /**
     * Set the user password credential establish the connection. This value is
     * used if no connection information is supplied by the application when
     * attempting to create a connection.
     *
     * @param password the password credential used to establish the connection; may
     *                 be null
     */
    public void setPassword(String password) {
        connectionPoolDataSource.setPassword(password);
    }

    /**
     * Return the database name.
     *
     * @return the database name
     */
    public String getDatabaseName() {
        return connectionPoolDataSource.getDatabaseName();
    }

    /**
     * Set the database name.
     *
     * @param databaseName the database name
     */
    public void setDatabaseName(String databaseName) {
        connectionPoolDataSource.setDatabaseName(databaseName);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getPortNumber()
     */
    public Integer getPortNumber() {
        return connectionPoolDataSource.getPortNumber();
    }

    /**
     * @param portNumber
     * @see org.postgresql.ds.common.BaseDataSource#setPortNumber(int)
     */
    public void setPortNumber(Integer portNumber) {
        connectionPoolDataSource.setPortNumber(portNumber);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getPrepareThreshold()
     */
    public Integer getPrepareThreshold() {
        return connectionPoolDataSource.getPrepareThreshold();
    }

    /**
     * @param threshold
     * @see org.postgresql.ds.common.BaseDataSource#setPrepareThreshold(int)
     */
    public void setPrepareThreshold(Integer threshold) {
        connectionPoolDataSource.setPrepareThreshold(threshold);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getServerName()
     */
    public String getServerName() {
        return connectionPoolDataSource.getServerName();
    }

    /**
     * @param serverName
     * @see org.postgresql.ds.common.BaseDataSource#setServerName(java.lang.String)
     */
    public void setServerName(String serverName) {
        connectionPoolDataSource.setServerName(serverName);
    }

    /**
     * @see org.postgresql.ds.common.BaseDataSource#setLoginTimeout(java.lang.String)
     */
    public void setLoginTimeout(int s) throws SQLException {
        connectionPoolDataSource.setLoginTimeout(s);
    }

    /**
     * @param enabled
     * @see org.postgresql.ds.common.BaseDataSource#setSsl(boolean)
     */
    public void setSsl(boolean enabled) {
        connectionPoolDataSource.setSsl(enabled);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getSsl()
     */
    public boolean getSsl() {
        return connectionPoolDataSource.getSsl();
    }

    /**
     * @param classname
     * @see org.postgresql.ds.common.BaseDataSource#setSslfactory(java.lang.String)
     */
    public void setSslfactory(String classname) {
        connectionPoolDataSource.setSslfactory(classname);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getSslFactory()
     */
    public String getSslfactory() {
        return connectionPoolDataSource.getSslfactory();
    }

    /**
     * @param defaultAutoCommit
     * @see org.postgresql.ds.common.BaseDataSource#setDefaultAutoCommit(boolean)
     */
    public void setDefaultAutoCommit(boolean defaultAutoCommit)
    {
        connectionPoolDataSource.setDefaultAutoCommit(defaultAutoCommit);
    }

    /**
     * @return
     * @see org.postgresql.ds.PGConnectionPoolDataSource#isDefaultAutoCommit()
     */
    public boolean getDefaultAutoCommit() 
    {
        return connectionPoolDataSource.isDefaultAutoCommit();
    }
}
